@@ -1,12 +1,12 @@
-# -*- coding: utf-8 -*-
-import io
 import os.path
 from urllib.parse import urlparse
 
-from chaoslib.exceptions import InvalidSource
-from logzero import logger
 import requests
 import yaml
+from logzero import logger
+
+from chaoslib.exceptions import InvalidSource
+
 try:
     import simplejson as json
     from simplejson.errors import JSONDecodeError
@@ -18,7 +18,6 @@ from chaoslib.control import controls
 from chaoslib.exceptions import InvalidExperiment
 from chaoslib.types import Experiment, Settings
 
-
 __all__ = ["load_experiment"]
 
 
@@ -26,19 +25,19 @@ def parse_experiment_from_file(path: str) -> Experiment:
     """
     Parse the given experiment from `path` and return it.
     """
-    with io.open(path) as f:
+    with open(path) as f:
         p, ext = os.path.splitext(path)
         if ext in (".yaml", ".yml"):
             try:
                 return yaml.safe_load(f)
             except yaml.YAMLError as ye:
-                raise InvalidSource(
-                    "Failed parsing YAML experiment: {}".format(str(ye)))
+                raise InvalidSource(f"Failed parsing YAML experiment: {str(ye)}")
         elif ext == ".json":
             return json.load(f)
 
     raise InvalidExperiment(
-        "only files with json, yaml or yml extensions are supported")
+        "only files with json, yaml or yml extensions are supported"
+    )
 
 
 def parse_experiment_from_http(response: requests.Response) -> Experiment:
@@ -47,15 +46,14 @@ def parse_experiment_from_http(response: requests.Response) -> Experiment:
     """
     content_type = response.headers.get("Content-Type")
 
-    if 'application/json' in content_type:
+    if "application/json" in content_type:
         return response.json()
-    elif 'application/x-yaml' in content_type or 'text/yaml' in content_type:
+    elif "application/x-yaml" in content_type or "text/yaml" in content_type:
         try:
             return yaml.safe_load(response.text)
         except yaml.YAMLError as ye:
-            raise InvalidSource(
-                "Failed parsing YAML experiment: {}".format(str(ye)))
-    elif 'text/plain' in content_type:
+            raise InvalidSource(f"Failed parsing YAML experiment: {str(ye)}")
+    elif "text/plain" in content_type:
         content = response.text
         try:
             return json.loads(content)
@@ -66,11 +64,13 @@ def parse_experiment_from_http(response: requests.Response) -> Experiment:
                 pass
 
     raise InvalidExperiment(
-        "only files with json, yaml or yml extensions are supported")
+        "only files with json, yaml or yml extensions are supported"
+    )
 
 
-def load_experiment(experiment_source: str, settings: Settings = None,
-                    verify_tls: bool = True) -> Experiment:
+def load_experiment(
+    experiment_source: str, settings: Settings = None, verify_tls: bool = True
+) -> Experiment:
     """
     Load an experiment from the given source.
 
@@ -103,30 +103,27 @@ def load_experiment(experiment_source: str, settings: Settings = None,
 
         p = urlparse(experiment_source)
         if not p.scheme and not os.path.exists(p.path):
-            raise InvalidSource('Path "{}" does not exist.'.format(p.path))
+            raise InvalidSource(f'Path "{p.path}" does not exist.')
 
         if p.scheme not in ("http", "https"):
-            raise InvalidSource(
-                "'{}' is not a supported source scheme.".format(p.scheme))
+            raise InvalidSource(f"'{p.scheme}' is not a supported source scheme.")
 
-        headers = {
-            "Accept": "application/json, application/x-yaml"
-        }
+        headers = {"Accept": "application/json, application/x-yaml"}
         if settings:
             auths = settings.get("auths", [])
             for domain in auths:
                 if domain == p.netloc:
                     auth = auths[domain]
-                    headers["Authorization"] = '{} {}'.format(
-                        auth["type"], auth["value"])
+                    headers["Authorization"] = "{} {}".format(
+                        auth["type"], auth["value"]
+                    )
                     break
 
         r = requests.get(experiment_source, headers=headers, verify=verify_tls)
         if r.status_code != 200:
-            raise InvalidSource(
-                "Failed to fetch the experiment: {}".format(r.text))
+            raise InvalidSource(f"Failed to fetch the experiment: {r.text}")
 
-        logger.debug("Fetched experiment: \n{}".format(r.text))
+        logger.debug(f"Fetched experiment: \n{r.text}")
         parsed = parse_experiment_from_http(r)
         control.with_state(parsed)
         return parsed
