@@ -1,5 +1,5 @@
 from chaoslib.exceptions import InterruptExecution
-from chaoslib.types import Activity, Run
+from chaoslib.types import Activity
 
 
 def before_activity_control(context: Activity, **kwargs):
